@@ -1,4 +1,4 @@
-# Copyright (c) 2021, Panagiotis Tsirigotis
+# Copyright (c) 2021, 2022, Panagiotis Tsirigotis
 
 # This file is part of linuxnet-iptables.
 #
@@ -36,6 +36,11 @@ from .deps import get_logger
 
 _logger = get_logger('linuxnet.iptables.match')
 
+class _CriteriaExhaustedError(Exception):
+    """Raised to indicate that criteria parsing has completed
+    """
+
+
 class Criterion:
     """
     This class is used to *express* an **iptables(8)** match criterion;
@@ -1539,6 +1544,121 @@ class CommentMatch(Match):
             words.append(val)
         return CommentMatch().comment().equals(' '.join(words))
 
+#
+#######################################################################
+#
+# TTL
+#
+
+class TtlCriterion(Criterion):
+    """A criterion for a TTL value comparison used by :class:`TtlMatch`.
+    """
+
+    _EQ_COMP = '=='
+    _LT_COMP = '<'
+    _GT_COMP = '>'
+
+    def __init__(self, match: Match):
+        super().__init__(match)
+        self.__value = None
+        self.__comp = None
+
+    def __eq__(self, other):
+        return isinstance(other, TtlCriterion) and super().__eq__(other)
+
+    def get_value(self):
+        """Returns the value that the criterion is comparing against
+        and the comparison operation (as a string)
+
+        :rtype: tuple of (int, str)
+        """
+        return (self.__value, self.__comp)
+
+    def equals(self, value: int) -> Match: # pylint: disable=arguments-differ
+        """Check if the packet TTL is equal to ``value``
+
+        :param value: the TTL value
+        """
+        self.__value = value
+        self.__comp = self._EQ_COMP
+        return self._set_polarity(True)
+
+    def less_than(self, value: int) -> Match:
+        """Check if the packet TTL is less than ``value``
+
+        :param value: the TTL value
+        """
+        self.__value = value
+        self.__comp = self._LT_COMP
+        return self._set_polarity(True)
+
+    def greater_than(self, value: int) -> Match:
+        """Check if the packet TTL is greater than ``value``
+
+        :param value: the TTL value
+        """
+        self.__value = value
+        self.__comp = self._GT_COMP
+        return self._set_polarity(True)
+
+    def _crit_iptables_args(self) -> List[str]:
+        """Returns **iptables(8)** arguments for the specified TTL comparison
+        """
+        if self.__comp == self._EQ_COMP:
+            return ['--ttl-eq', str(self.__value)]
+        if self.__comp == self._LT_COMP:
+            return ['--ttl-lt', str(self.__value)]
+        return ['--ttl-gt', str(self.__value)]
+
+
+class TtlMatch(Match):
+    """Match against the packet TTL value
+    """
+    def __init__(self):
+        self.__ttl_crit = None
+
+    def __eq__(self, other):
+        return (isinstance(other, TtlMatch) and
+                self.ttl() == other.ttl())
+
+    def ttl(self) -> TtlCriterion:
+        """Returns the TTL criterion
+        """
+        if self.__ttl_crit is None:
+            self.__ttl_crit = TtlCriterion(self)
+        return self.__ttl_crit
+
+    def to_iptables_args(self) -> List[str]:
+        """Returns **iptables(8)** arguments for this match
+        """
+        return self.build_iptables_args('ttl', [self.__ttl_crit])
+
+    @classmethod
+    def _parse(                  # pylint: disable=unused-argument
+                cls, criteria_iter, match_name: str,
+                negation: Optional[str]) -> Match:
+        """Parse the TTL criterion
+        """
+        val = next(criteria_iter)
+        if val != 'match':
+            # It must be a TTL target
+            criteria_iter.put_back(val)
+            raise _CriteriaExhaustedError()
+        val = next(criteria_iter)
+        if val != 'TTL':
+            raise IptablesParsingError(f"expected 'TTL', found {val} ")
+        comp = next(criteria_iter)
+        value = int(next(criteria_iter))
+        if comp == '==':
+            return TtlMatch().ttl().equals(value)
+        if comp == '!=':
+            return TtlMatch().ttl().not_equals(value)
+        if comp == '>':
+            return TtlMatch().ttl().greater_than(value)
+        if comp == '<':
+            return TtlMatch().ttl().less_than(value)
+        raise IptablesParsingError(f"bad TTL comparison: '{comp}' ")
+
 #
 #######################################################################
 #
@@ -1558,6 +1678,7 @@ _parser_map = {
                 'state'         : StateMatch._parse,
                 'tcp'           : TcpMatch._parse,
                 'tcpmss'        : TcpmssMatch._parse,
+                'TTL'           : TtlMatch._parse,
                 'udp'           : UdpMatch._parse,
                 '/*'            : CommentMatch._parse
                 }
@@ -1625,10 +1746,14 @@ def parse_criteria(field_iter) -> List[Match]:
             # This code parses only a subset of possible criteria
             # It needs to be expanded.
             #
+            match = None
             parser = _parser_map.get(match_name)
             if parser is not None:
-                match = parser(field_iter, match_name, negation)
-            else:
+                try:
+                    match = parser(field_iter, match_name, negation)
+                except _CriteriaExhaustedError:
+                    pass
+            if match is None:
                 # We don't know if it is a match criterion that we don't
                 # know about, a target name, or a target option.
                 # Let the caller figure it out.
