@@ -609,6 +609,95 @@ class MasqueradeTarget(Target):
                                         is_random=is_random)
 
 
+class TtlTarget(Target):
+    """This class provides access to the ``TTL`` target
+    """
+    def __init__(self,
+                        set_ttl_to: Optional[int] =None,
+                        inc_ttl_by: Optional[int] =None,
+                        dec_ttl_by: Optional[int] =None):
+        """
+        :param set_ttl_to: set the TTL to this value
+        :param inc_ttl_by: increase the TTL by this value
+        :param dec_ttl_by: decrease the TTL by this value
+
+        Exactly one of ``set_ttl_to``, ``inc_ttl_by``,
+        ``dec_ttl_by`` should not be equal to ``None``.
+        """
+        super().__init__('TTL', terminates=False)
+        if set_ttl_to is None and inc_ttl_by is None and dec_ttl_by is None:
+            raise IptablesError('no TTL operation specified')
+        self.__set_ttl_to = set_ttl_to
+        self.__inc_ttl_by = inc_ttl_by
+        self.__dec_ttl_by = dec_ttl_by
+
+    def get_ttl_value(self) -> Optional[int]:
+        """Returns the value to set the TTL to
+        """
+        return self.__set_ttl_to
+
+    def get_ttl_inc(self) -> Optional[int]:
+        """Returns the TTL increment value
+        """
+        return self.__inc_ttl_by
+
+    def get_ttl_dec(self) -> Optional[int]:
+        """Returns the TTL decrement value
+        """
+        return self.__dec_ttl_by
+
+    def to_iptables_args(self) -> List[str]:
+        """Returns a list of **iptables(8)** arguments
+        """
+        retval = super().to_iptables_args()
+        if self.__set_ttl_to is not None:
+            retval += ['--ttl-set', str(self.__set_ttl_to)]
+        elif self.__inc_ttl_by is not None:
+            retval += ['--ttl-inc', str(self.__inc_ttl_by)]
+        else:
+            retval += ['--ttl-dec', str(self.__dec_ttl_by)]
+        return retval
+
+    @classmethod
+    def _parse(cls, field_iter) -> Target:
+        """Parse the TTL target options
+        """
+        field_iter.forward_past('TTL')
+        set_ttl_to = None
+        inc_ttl_by = None
+        dec_ttl_by = None
+        try:
+            ttl_op = next(field_iter)
+            if ttl_op == 'set':
+                val = next(field_iter)
+                if val != 'to':
+                    raise IptablesParsingError(
+                        f"TTL target: expected 'to', got '{val}'")
+                set_ttl_to = int(next(field_iter))
+            elif ttl_op == 'decrement':
+                val = next(field_iter)
+                if val != 'by':
+                    raise IptablesParsingError(
+                        f"TTL target: expected 'by', got '{val}'")
+                dec_ttl_by = int(next(field_iter))
+            elif ttl_op == 'increment':
+                val = next(field_iter)
+                if val != 'by':
+                    raise IptablesParsingError(
+                        f"TTL target: expected 'by', got '{val}'")
+                inc_ttl_by = int(next(field_iter))
+            else:
+                raise IptablesParsingError(
+                        f"TTL target: unexpected operation: '{ttl_op}'")
+        except ValueError as valerr:
+            raise IptablesParsingError(
+                        f'bad TTL {ttl_op} value: {val}') from valerr
+        except StopIteration as stopit:
+            raise IptablesParsingError('incomplete TTL target') from stopit
+        target = TtlTarget(set_ttl_to, inc_ttl_by, dec_ttl_by)
+        return target
+
+
 class ChainTarget(Target):
     """This class handles a target that is a chain
     """
@@ -762,5 +851,7 @@ def parse_target(               # pylint: disable=too-many-return-statements
         return DnatTarget._parse(field_iter)
     if target_name == 'MASQUERADE':
         return MasqueradeTarget._parse(field_iter)
+    if target_name == 'TTL':
+        return TtlTarget._parse(field_iter)
     return UnparsedTarget(target_name, field_iter)
 # pylint: enable=protected-access
